"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ProjReply(google.protobuf.message.Message):
    """投屏"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CMD_TYPE_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    AID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    VIDEO_TYPE_FIELD_NUMBER: builtins.int
    EP_ID_FIELD_NUMBER: builtins.int
    SEASON_ID_FIELD_NUMBER: builtins.int
    SEEK_TS_FIELD_NUMBER: builtins.int
    EXTRA_FIELD_NUMBER: builtins.int
    cmd_type: builtins.int
    """投屏命令
    1:起播 2:快进 3:快退 4:seek播放进度 5:暂停 6:暂停恢复
    """

    mid: builtins.int
    """用户id"""

    aid: builtins.int
    """稿件id"""

    cid: builtins.int
    """视频id"""

    video_type: builtins.int
    """视频类型
    0:ugc 1:pgc 2:pugv
    """

    ep_id: builtins.int
    """单集id，pgc和pugv需要传"""

    season_id: builtins.int
    """剧集id"""

    seek_ts: builtins.int
    """seek 的位置，cmd位seek时有值，单位秒"""

    extra: typing.Text
    """其他指令对应内容"""

    def __init__(self,
        *,
        cmd_type: builtins.int = ...,
        mid: builtins.int = ...,
        aid: builtins.int = ...,
        cid: builtins.int = ...,
        video_type: builtins.int = ...,
        ep_id: builtins.int = ...,
        season_id: builtins.int = ...,
        seek_ts: builtins.int = ...,
        extra: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid",b"aid","cid",b"cid","cmd_type",b"cmd_type","ep_id",b"ep_id","extra",b"extra","mid",b"mid","season_id",b"season_id","seek_ts",b"seek_ts","video_type",b"video_type"]) -> None: ...
global___ProjReply = ProjReply

class LiveStatusNotify(google.protobuf.message.Message):
    """直播状态"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    STATUS_FIELD_NUMBER: builtins.int
    MSG_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    status: builtins.int
    """直播状态
    1:开播 2:关播 3:截流 4:截流恢复
    """

    msg: typing.Text
    """文案"""

    cid: builtins.int
    """直播房间号"""

    def __init__(self,
        *,
        status: builtins.int = ...,
        msg: typing.Text = ...,
        cid: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cid",b"cid","msg",b"msg","status",b"status"]) -> None: ...
global___LiveStatusNotify = LiveStatusNotify

class EsportsNotify(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CID_FIELD_NUMBER: builtins.int
    cid: builtins.int
    """直播房间号"""

    def __init__(self,
        *,
        cid: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cid",b"cid"]) -> None: ...
global___EsportsNotify = EsportsNotify

class PublicityNotify(google.protobuf.message.Message):
    """直播插卡"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PUBLICITY_ID_FIELD_NUMBER: builtins.int
    ROOM_ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    publicity_id: builtins.int
    """插卡id"""

    room_id: builtins.int
    """直播房间号"""

    status: builtins.int
    """直播间状态
    0:未开播 1:直播中 2:轮播中
    """

    def __init__(self,
        *,
        publicity_id: builtins.int = ...,
        room_id: builtins.int = ...,
        status: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["publicity_id",b"publicity_id","room_id",b"room_id","status",b"status"]) -> None: ...
global___PublicityNotify = PublicityNotify

class LiveSkipNotify(google.protobuf.message.Message):
    """直转点"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    LIVE_ID_FIELD_NUMBER: builtins.int
    live_id: builtins.int
    """直播id"""

    def __init__(self,
        *,
        live_id: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["live_id",b"live_id"]) -> None: ...
global___LiveSkipNotify = LiveSkipNotify



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class AddParams(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    A_FIELD_NUMBER: builtins.int
    B_FIELD_NUMBER: builtins.int
    a: builtins.int
    """"""

    b: builtins.int
    """"""

    def __init__(self,
        *,
        a: builtins.int = ...,
        b: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["a",b"a","b",b"b"]) -> None: ...
global___AddParams = AddParams

class AddResult(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    R_FIELD_NUMBER: builtins.int
    r: builtins.int
    """"""

    def __init__(self,
        *,
        r: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["r",b"r"]) -> None: ...
global___AddResult = AddResult

class TestResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TASKID_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    EXTRA_FIELD_NUMBER: builtins.int
    taskid: builtins.int
    """任务id"""

    timestamp: builtins.int
    """时间戳"""

    message: typing.Text
    """消息"""

    @property
    def extra(self) -> google.protobuf.any_pb2.Any:
        """扩展"""
        pass
    def __init__(self,
        *,
        taskid: builtins.int = ...,
        timestamp: builtins.int = ...,
        message: typing.Text = ...,
        extra: typing.Optional[google.protobuf.any_pb2.Any] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["extra",b"extra"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["extra",b"extra","message",b"message","taskid",b"taskid","timestamp",b"timestamp"]) -> None: ...
global___TestResp = TestResp



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from bilireq.grpc.protos.bilibili.community.service.dm.v1 import dm_pb2 as bilibili_dot_community_dot_service_dot_dm_dot_v1_dot_dm__pb2


class DMStub(object):
    """弹幕
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.DmSegMobile = channel.unary_unary(
                '/bilibili.community.service.dm.v1.DM/DmSegMobile',
                request_serializer=bilibili_dot_community_dot_service_dot_dm_dot_v1_dot_dm__pb2.DmSegMobileReq.SerializeToString,
                response_deserializer=bilibili_dot_community_dot_service_dot_dm_dot_v1_dot_dm__pb2.DmSegMobileReply.FromString,
                )
        self.DmView = channel.unary_unary(
                '/bilibili.community.service.dm.v1.DM/DmView',
                request_serializer=bilibili_dot_community_dot_service_dot_dm_dot_v1_dot_dm__pb2.DmViewReq.SerializeToString,
                response_deserializer=bilibili_dot_community_dot_service_dot_dm_dot_v1_dot_dm__pb2.DmViewReply.FromString,
                )
        self.DmPlayerConfig = channel.unary_unary(
                '/bilibili.community.service.dm.v1.DM/DmPlayerConfig',
                request_serializer=bilibili_dot_community_dot_service_dot_dm_dot_v1_dot_dm__pb2.DmPlayerConfigReq.SerializeToString,
                response_deserializer=bilibili_dot_community_dot_service_dot_dm_dot_v1_dot_dm__pb2.Response.FromString,
                )
        self.DmSegOtt = channel.unary_unary(
                '/bilibili.community.service.dm.v1.DM/DmSegOtt',
                request_serializer=bilibili_dot_community_dot_service_dot_dm_dot_v1_dot_dm__pb2.DmSegOttReq.SerializeToString,
                response_deserializer=bilibili_dot_community_dot_service_dot_dm_dot_v1_dot_dm__pb2.DmSegOttReply.FromString,
                )
        self.DmSegSDK = channel.unary_unary(
                '/bilibili.community.service.dm.v1.DM/DmSegSDK',
                request_serializer=bilibili_dot_community_dot_service_dot_dm_dot_v1_dot_dm__pb2.DmSegSDKReq.SerializeToString,
                response_deserializer=bilibili_dot_community_dot_service_dot_dm_dot_v1_dot_dm__pb2.DmSegSDKReply.FromString,
                )
        self.DmExpoReport = channel.unary_unary(
                '/bilibili.community.service.dm.v1.DM/DmExpoReport',
                request_serializer=bilibili_dot_community_dot_service_dot_dm_dot_v1_dot_dm__pb2.DmExpoReportReq.SerializeToString,
                response_deserializer=bilibili_dot_community_dot_service_dot_dm_dot_v1_dot_dm__pb2.DmExpoReportRes.FromString,
                )


class DMServicer(object):
    """弹幕
    """

    def DmSegMobile(self, request, context):
        """获取分段弹幕
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DmView(self, request, context):
        """客户端弹幕元数据 字幕、分段、防挡蒙版等
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DmPlayerConfig(self, request, context):
        """修改弹幕配置
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DmSegOtt(self, request, context):
        """ott弹幕列表
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DmSegSDK(self, request, context):
        """SDK弹幕列表
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DmExpoReport(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DMServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'DmSegMobile': grpc.unary_unary_rpc_method_handler(
                    servicer.DmSegMobile,
                    request_deserializer=bilibili_dot_community_dot_service_dot_dm_dot_v1_dot_dm__pb2.DmSegMobileReq.FromString,
                    response_serializer=bilibili_dot_community_dot_service_dot_dm_dot_v1_dot_dm__pb2.DmSegMobileReply.SerializeToString,
            ),
            'DmView': grpc.unary_unary_rpc_method_handler(
                    servicer.DmView,
                    request_deserializer=bilibili_dot_community_dot_service_dot_dm_dot_v1_dot_dm__pb2.DmViewReq.FromString,
                    response_serializer=bilibili_dot_community_dot_service_dot_dm_dot_v1_dot_dm__pb2.DmViewReply.SerializeToString,
            ),
            'DmPlayerConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.DmPlayerConfig,
                    request_deserializer=bilibili_dot_community_dot_service_dot_dm_dot_v1_dot_dm__pb2.DmPlayerConfigReq.FromString,
                    response_serializer=bilibili_dot_community_dot_service_dot_dm_dot_v1_dot_dm__pb2.Response.SerializeToString,
            ),
            'DmSegOtt': grpc.unary_unary_rpc_method_handler(
                    servicer.DmSegOtt,
                    request_deserializer=bilibili_dot_community_dot_service_dot_dm_dot_v1_dot_dm__pb2.DmSegOttReq.FromString,
                    response_serializer=bilibili_dot_community_dot_service_dot_dm_dot_v1_dot_dm__pb2.DmSegOttReply.SerializeToString,
            ),
            'DmSegSDK': grpc.unary_unary_rpc_method_handler(
                    servicer.DmSegSDK,
                    request_deserializer=bilibili_dot_community_dot_service_dot_dm_dot_v1_dot_dm__pb2.DmSegSDKReq.FromString,
                    response_serializer=bilibili_dot_community_dot_service_dot_dm_dot_v1_dot_dm__pb2.DmSegSDKReply.SerializeToString,
            ),
            'DmExpoReport': grpc.unary_unary_rpc_method_handler(
                    servicer.DmExpoReport,
                    request_deserializer=bilibili_dot_community_dot_service_dot_dm_dot_v1_dot_dm__pb2.DmExpoReportReq.FromString,
                    response_serializer=bilibili_dot_community_dot_service_dot_dm_dot_v1_dot_dm__pb2.DmExpoReportRes.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'bilibili.community.service.dm.v1.DM', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DM(object):
    """弹幕
    """

    @staticmethod
    def DmSegMobile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.community.service.dm.v1.DM/DmSegMobile',
            bilibili_dot_community_dot_service_dot_dm_dot_v1_dot_dm__pb2.DmSegMobileReq.SerializeToString,
            bilibili_dot_community_dot_service_dot_dm_dot_v1_dot_dm__pb2.DmSegMobileReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DmView(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.community.service.dm.v1.DM/DmView',
            bilibili_dot_community_dot_service_dot_dm_dot_v1_dot_dm__pb2.DmViewReq.SerializeToString,
            bilibili_dot_community_dot_service_dot_dm_dot_v1_dot_dm__pb2.DmViewReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DmPlayerConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.community.service.dm.v1.DM/DmPlayerConfig',
            bilibili_dot_community_dot_service_dot_dm_dot_v1_dot_dm__pb2.DmPlayerConfigReq.SerializeToString,
            bilibili_dot_community_dot_service_dot_dm_dot_v1_dot_dm__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DmSegOtt(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.community.service.dm.v1.DM/DmSegOtt',
            bilibili_dot_community_dot_service_dot_dm_dot_v1_dot_dm__pb2.DmSegOttReq.SerializeToString,
            bilibili_dot_community_dot_service_dot_dm_dot_v1_dot_dm__pb2.DmSegOttReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DmSegSDK(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.community.service.dm.v1.DM/DmSegSDK',
            bilibili_dot_community_dot_service_dot_dm_dot_v1_dot_dm__pb2.DmSegSDKReq.SerializeToString,
            bilibili_dot_community_dot_service_dot_dm_dot_v1_dot_dm__pb2.DmSegSDKReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DmExpoReport(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.community.service.dm.v1.DM/DmExpoReport',
            bilibili_dot_community_dot_service_dot_dm_dot_v1_dot_dm__pb2.DmExpoReportReq.SerializeToString,
            bilibili_dot_community_dot_service_dot_dm_dot_v1_dot_dm__pb2.DmExpoReportRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class RegionConfig(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SCENES_NAME_FIELD_NUMBER: builtins.int
    SCENES_TYPE_FIELD_NUMBER: builtins.int
    scenes_name: typing.Text
    """"""

    scenes_type: typing.Text
    """"""

    def __init__(self,
        *,
        scenes_name: typing.Text = ...,
        scenes_type: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["scenes_name",b"scenes_name","scenes_type",b"scenes_type"]) -> None: ...
global___RegionConfig = RegionConfig

class RegionInfo(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TID_FIELD_NUMBER: builtins.int
    REID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    LOGO_FIELD_NUMBER: builtins.int
    GOTO_FIELD_NUMBER: builtins.int
    PARAM_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    IS_BANGUMI_FIELD_NUMBER: builtins.int
    CHILDREN_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    tid: builtins.int
    """"""

    reid: builtins.int
    """"""

    name: typing.Text
    """"""

    logo: typing.Text
    """"""

    goto: typing.Text
    """"""

    param: typing.Text
    """"""

    uri: typing.Text
    """"""

    type: builtins.int
    """"""

    is_bangumi: builtins.int
    """"""

    @property
    def children(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RegionInfo]:
        """"""
        pass
    @property
    def config(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RegionConfig]:
        """"""
        pass
    def __init__(self,
        *,
        tid: builtins.int = ...,
        reid: builtins.int = ...,
        name: typing.Text = ...,
        logo: typing.Text = ...,
        goto: typing.Text = ...,
        param: typing.Text = ...,
        uri: typing.Text = ...,
        type: builtins.int = ...,
        is_bangumi: builtins.int = ...,
        children: typing.Optional[typing.Iterable[global___RegionInfo]] = ...,
        config: typing.Optional[typing.Iterable[global___RegionConfig]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["children",b"children","config",b"config","goto",b"goto","is_bangumi",b"is_bangumi","logo",b"logo","name",b"name","param",b"param","reid",b"reid","tid",b"tid","type",b"type","uri",b"uri"]) -> None: ...
global___RegionInfo = RegionInfo

class RegionReply(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    REGIONS_FIELD_NUMBER: builtins.int
    @property
    def regions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RegionInfo]:
        """"""
        pass
    def __init__(self,
        *,
        regions: typing.Optional[typing.Iterable[global___RegionInfo]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["regions",b"regions"]) -> None: ...
global___RegionReply = RegionReply

class RegionReq(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    LANG_FIELD_NUMBER: builtins.int
    lang: typing.Text
    """"""

    def __init__(self,
        *,
        lang: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["lang",b"lang"]) -> None: ...
global___RegionReq = RegionReq



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bilireq.grpc.protos.bilibili.app.card.v1.common_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class DoubleCards(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SMALL_COVER_V2_FIELD_NUMBER: builtins.int
    ONE_PIC_V2_FIELD_NUMBER: builtins.int
    THREE_PIC_V2_FIELD_NUMBER: builtins.int
    @property
    def small_cover_v2(self) -> global___SmallCoverV2:
        """"""
        pass
    @property
    def one_pic_v2(self) -> global___OnePicV2:
        """"""
        pass
    @property
    def three_pic_v2(self) -> global___ThreePicV2:
        """"""
        pass
    def __init__(self,
        *,
        small_cover_v2: typing.Optional[global___SmallCoverV2] = ...,
        one_pic_v2: typing.Optional[global___OnePicV2] = ...,
        three_pic_v2: typing.Optional[global___ThreePicV2] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["Card",b"Card","one_pic_v2",b"one_pic_v2","small_cover_v2",b"small_cover_v2","three_pic_v2",b"three_pic_v2"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["Card",b"Card","one_pic_v2",b"one_pic_v2","small_cover_v2",b"small_cover_v2","three_pic_v2",b"three_pic_v2"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["Card",b"Card"]) -> typing.Optional[typing_extensions.Literal["small_cover_v2","one_pic_v2","three_pic_v2"]]: ...
global___DoubleCards = DoubleCards

class SmallCoverV2(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BASE_FIELD_NUMBER: builtins.int
    COVER_GIF_FIELD_NUMBER: builtins.int
    COVER_BLUR_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_1_FIELD_NUMBER: builtins.int
    COVER_LEFT_ICON_1_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_2_FIELD_NUMBER: builtins.int
    COVER_LEFT_ICON_2_FIELD_NUMBER: builtins.int
    COVER_RIGHT_TEXT_FIELD_NUMBER: builtins.int
    COVER_RIGHT_ICON_FIELD_NUMBER: builtins.int
    COVER_RIGHT_BACKGROUND_COLOR_FIELD_NUMBER: builtins.int
    SUBTITLE_FIELD_NUMBER: builtins.int
    BADGE_FIELD_NUMBER: builtins.int
    RCMD_REASON_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    AVATAR_FIELD_NUMBER: builtins.int
    OFFICIAL_ICON_FIELD_NUMBER: builtins.int
    CAN_PLAY_FIELD_NUMBER: builtins.int
    RCMD_REASON_STYLE_FIELD_NUMBER: builtins.int
    RCMD_REASON_STYLE_V2_FIELD_NUMBER: builtins.int
    LIKE_BUTTON_FIELD_NUMBER: builtins.int
    @property
    def base(self) -> bilibili.app.card.v1.common_pb2.Base:
        """"""
        pass
    cover_gif: typing.Text
    """"""

    cover_blur: builtins.int
    """"""

    cover_left_text_1: typing.Text
    """"""

    cover_left_icon_1: builtins.int
    """"""

    cover_left_text_2: typing.Text
    """"""

    cover_left_icon_2: builtins.int
    """"""

    cover_right_text: typing.Text
    """"""

    cover_right_icon: builtins.int
    """"""

    cover_right_background_color: typing.Text
    """"""

    subtitle: typing.Text
    """"""

    badge: typing.Text
    """"""

    rcmd_reason: typing.Text
    """"""

    desc: typing.Text
    """"""

    @property
    def avatar(self) -> bilibili.app.card.v1.common_pb2.Avatar:
        """"""
        pass
    official_icon: builtins.int
    """"""

    can_play: builtins.int
    """"""

    @property
    def rcmd_reason_style(self) -> bilibili.app.card.v1.common_pb2.ReasonStyle:
        """"""
        pass
    @property
    def rcmd_reason_style_v2(self) -> bilibili.app.card.v1.common_pb2.ReasonStyle:
        """"""
        pass
    @property
    def like_button(self) -> bilibili.app.card.v1.common_pb2.LikeButton:
        """"""
        pass
    def __init__(self,
        *,
        base: typing.Optional[bilibili.app.card.v1.common_pb2.Base] = ...,
        cover_gif: typing.Text = ...,
        cover_blur: builtins.int = ...,
        cover_left_text_1: typing.Text = ...,
        cover_left_icon_1: builtins.int = ...,
        cover_left_text_2: typing.Text = ...,
        cover_left_icon_2: builtins.int = ...,
        cover_right_text: typing.Text = ...,
        cover_right_icon: builtins.int = ...,
        cover_right_background_color: typing.Text = ...,
        subtitle: typing.Text = ...,
        badge: typing.Text = ...,
        rcmd_reason: typing.Text = ...,
        desc: typing.Text = ...,
        avatar: typing.Optional[bilibili.app.card.v1.common_pb2.Avatar] = ...,
        official_icon: builtins.int = ...,
        can_play: builtins.int = ...,
        rcmd_reason_style: typing.Optional[bilibili.app.card.v1.common_pb2.ReasonStyle] = ...,
        rcmd_reason_style_v2: typing.Optional[bilibili.app.card.v1.common_pb2.ReasonStyle] = ...,
        like_button: typing.Optional[bilibili.app.card.v1.common_pb2.LikeButton] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["avatar",b"avatar","base",b"base","like_button",b"like_button","rcmd_reason_style",b"rcmd_reason_style","rcmd_reason_style_v2",b"rcmd_reason_style_v2"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["avatar",b"avatar","badge",b"badge","base",b"base","can_play",b"can_play","cover_blur",b"cover_blur","cover_gif",b"cover_gif","cover_left_icon_1",b"cover_left_icon_1","cover_left_icon_2",b"cover_left_icon_2","cover_left_text_1",b"cover_left_text_1","cover_left_text_2",b"cover_left_text_2","cover_right_background_color",b"cover_right_background_color","cover_right_icon",b"cover_right_icon","cover_right_text",b"cover_right_text","desc",b"desc","like_button",b"like_button","official_icon",b"official_icon","rcmd_reason",b"rcmd_reason","rcmd_reason_style",b"rcmd_reason_style","rcmd_reason_style_v2",b"rcmd_reason_style_v2","subtitle",b"subtitle"]) -> None: ...
global___SmallCoverV2 = SmallCoverV2

class SmallCoverV3(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BASE_FIELD_NUMBER: builtins.int
    AVATAR_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_FIELD_NUMBER: builtins.int
    COVER_RIGHT_BUTTON_FIELD_NUMBER: builtins.int
    RCMD_REASON_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    OFFICIAL_ICON_FIELD_NUMBER: builtins.int
    CAN_PLAY_FIELD_NUMBER: builtins.int
    RCMD_REASON_STYLE_FIELD_NUMBER: builtins.int
    @property
    def base(self) -> bilibili.app.card.v1.common_pb2.Base:
        """"""
        pass
    @property
    def avatar(self) -> bilibili.app.card.v1.common_pb2.Avatar:
        """"""
        pass
    cover_left_text: typing.Text
    """"""

    @property
    def cover_right_button(self) -> bilibili.app.card.v1.common_pb2.Button:
        """"""
        pass
    rcmd_reason: typing.Text
    """"""

    desc: typing.Text
    """"""

    official_icon: builtins.int
    """"""

    can_play: builtins.int
    """"""

    @property
    def rcmd_reason_style(self) -> bilibili.app.card.v1.common_pb2.ReasonStyle:
        """"""
        pass
    def __init__(self,
        *,
        base: typing.Optional[bilibili.app.card.v1.common_pb2.Base] = ...,
        avatar: typing.Optional[bilibili.app.card.v1.common_pb2.Avatar] = ...,
        cover_left_text: typing.Text = ...,
        cover_right_button: typing.Optional[bilibili.app.card.v1.common_pb2.Button] = ...,
        rcmd_reason: typing.Text = ...,
        desc: typing.Text = ...,
        official_icon: builtins.int = ...,
        can_play: builtins.int = ...,
        rcmd_reason_style: typing.Optional[bilibili.app.card.v1.common_pb2.ReasonStyle] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["avatar",b"avatar","base",b"base","cover_right_button",b"cover_right_button","rcmd_reason_style",b"rcmd_reason_style"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["avatar",b"avatar","base",b"base","can_play",b"can_play","cover_left_text",b"cover_left_text","cover_right_button",b"cover_right_button","desc",b"desc","official_icon",b"official_icon","rcmd_reason",b"rcmd_reason","rcmd_reason_style",b"rcmd_reason_style"]) -> None: ...
global___SmallCoverV3 = SmallCoverV3

class MiddleCoverV2(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BASE_FIELD_NUMBER: builtins.int
    RATIO_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    BADGE_FIELD_NUMBER: builtins.int
    @property
    def base(self) -> bilibili.app.card.v1.common_pb2.Base:
        """"""
        pass
    ratio: builtins.int
    """"""

    desc: typing.Text
    """"""

    badge: typing.Text
    """"""

    def __init__(self,
        *,
        base: typing.Optional[bilibili.app.card.v1.common_pb2.Base] = ...,
        ratio: builtins.int = ...,
        desc: typing.Text = ...,
        badge: typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["base",b"base"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["badge",b"badge","base",b"base","desc",b"desc","ratio",b"ratio"]) -> None: ...
global___MiddleCoverV2 = MiddleCoverV2

class LargeCoverV2(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BASE_FIELD_NUMBER: builtins.int
    AVATAR_FIELD_NUMBER: builtins.int
    BADGE_FIELD_NUMBER: builtins.int
    COVER_RIGHT_BUTTON_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_1_FIELD_NUMBER: builtins.int
    COVER_LEFT_ICON_1_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_2_FIELD_NUMBER: builtins.int
    COVER_LEFT_ICON_2_FIELD_NUMBER: builtins.int
    RCMD_REASON_FIELD_NUMBER: builtins.int
    OFFICIAL_ICON_FIELD_NUMBER: builtins.int
    CAN_PLAY_FIELD_NUMBER: builtins.int
    RCMD_REASON_STYLE_FIELD_NUMBER: builtins.int
    SHOW_TOP_FIELD_NUMBER: builtins.int
    SHOW_BOTTOM_FIELD_NUMBER: builtins.int
    @property
    def base(self) -> bilibili.app.card.v1.common_pb2.Base:
        """"""
        pass
    @property
    def avatar(self) -> bilibili.app.card.v1.common_pb2.Avatar:
        """"""
        pass
    badge: typing.Text
    """"""

    @property
    def cover_right_button(self) -> bilibili.app.card.v1.common_pb2.Button:
        """"""
        pass
    cover_left_text_1: typing.Text
    """"""

    cover_left_icon_1: builtins.int
    """"""

    cover_left_text_2: typing.Text
    """"""

    cover_left_icon_2: builtins.int
    """"""

    rcmd_reason: typing.Text
    """"""

    official_icon: builtins.int
    """"""

    can_play: builtins.int
    """"""

    @property
    def rcmd_reason_style(self) -> bilibili.app.card.v1.common_pb2.ReasonStyle:
        """"""
        pass
    show_top: builtins.int
    """"""

    show_bottom: builtins.int
    """"""

    def __init__(self,
        *,
        base: typing.Optional[bilibili.app.card.v1.common_pb2.Base] = ...,
        avatar: typing.Optional[bilibili.app.card.v1.common_pb2.Avatar] = ...,
        badge: typing.Text = ...,
        cover_right_button: typing.Optional[bilibili.app.card.v1.common_pb2.Button] = ...,
        cover_left_text_1: typing.Text = ...,
        cover_left_icon_1: builtins.int = ...,
        cover_left_text_2: typing.Text = ...,
        cover_left_icon_2: builtins.int = ...,
        rcmd_reason: typing.Text = ...,
        official_icon: builtins.int = ...,
        can_play: builtins.int = ...,
        rcmd_reason_style: typing.Optional[bilibili.app.card.v1.common_pb2.ReasonStyle] = ...,
        show_top: builtins.int = ...,
        show_bottom: builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["avatar",b"avatar","base",b"base","cover_right_button",b"cover_right_button","rcmd_reason_style",b"rcmd_reason_style"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["avatar",b"avatar","badge",b"badge","base",b"base","can_play",b"can_play","cover_left_icon_1",b"cover_left_icon_1","cover_left_icon_2",b"cover_left_icon_2","cover_left_text_1",b"cover_left_text_1","cover_left_text_2",b"cover_left_text_2","cover_right_button",b"cover_right_button","official_icon",b"official_icon","rcmd_reason",b"rcmd_reason","rcmd_reason_style",b"rcmd_reason_style","show_bottom",b"show_bottom","show_top",b"show_top"]) -> None: ...
global___LargeCoverV2 = LargeCoverV2

class ThreeItemV2(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BASE_FIELD_NUMBER: builtins.int
    TITLE_ICON_FIELD_NUMBER: builtins.int
    MORE_URI_FIELD_NUMBER: builtins.int
    MORE_TEXT_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    @property
    def base(self) -> bilibili.app.card.v1.common_pb2.Base:
        """"""
        pass
    title_icon: builtins.int
    """"""

    more_uri: typing.Text
    """"""

    more_text: typing.Text
    """"""

    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ThreeItemV2Item]:
        """"""
        pass
    def __init__(self,
        *,
        base: typing.Optional[bilibili.app.card.v1.common_pb2.Base] = ...,
        title_icon: builtins.int = ...,
        more_uri: typing.Text = ...,
        more_text: typing.Text = ...,
        items: typing.Optional[typing.Iterable[global___ThreeItemV2Item]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["base",b"base"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["base",b"base","items",b"items","more_text",b"more_text","more_uri",b"more_uri","title_icon",b"title_icon"]) -> None: ...
global___ThreeItemV2 = ThreeItemV2

class ThreeItemV2Item(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BASE_FIELD_NUMBER: builtins.int
    COVER_LEFT_ICON_FIELD_NUMBER: builtins.int
    DESC_TEXT_1_FIELD_NUMBER: builtins.int
    DESC_ICON_1_FIELD_NUMBER: builtins.int
    DESC_TEXT_2_FIELD_NUMBER: builtins.int
    DESC_ICON_2_FIELD_NUMBER: builtins.int
    BADGE_FIELD_NUMBER: builtins.int
    @property
    def base(self) -> bilibili.app.card.v1.common_pb2.Base:
        """"""
        pass
    cover_left_icon: builtins.int
    """"""

    desc_text_1: typing.Text
    """"""

    desc_icon_1: builtins.int
    """"""

    desc_text_2: typing.Text
    """"""

    desc_icon_2: builtins.int
    """"""

    badge: typing.Text
    """"""

    def __init__(self,
        *,
        base: typing.Optional[bilibili.app.card.v1.common_pb2.Base] = ...,
        cover_left_icon: builtins.int = ...,
        desc_text_1: typing.Text = ...,
        desc_icon_1: builtins.int = ...,
        desc_text_2: typing.Text = ...,
        desc_icon_2: builtins.int = ...,
        badge: typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["base",b"base"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["badge",b"badge","base",b"base","cover_left_icon",b"cover_left_icon","desc_icon_1",b"desc_icon_1","desc_icon_2",b"desc_icon_2","desc_text_1",b"desc_text_1","desc_text_2",b"desc_text_2"]) -> None: ...
global___ThreeItemV2Item = ThreeItemV2Item

class SmallCoverV4(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BASE_FIELD_NUMBER: builtins.int
    COVER_BADGE_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    TITLE_RIGHT_TEXT_FIELD_NUMBER: builtins.int
    TITLE_RIGHT_PIC_FIELD_NUMBER: builtins.int
    @property
    def base(self) -> bilibili.app.card.v1.common_pb2.Base:
        """"""
        pass
    cover_badge: typing.Text
    """"""

    desc: typing.Text
    """"""

    title_right_text: typing.Text
    """"""

    title_right_pic: builtins.int
    """"""

    def __init__(self,
        *,
        base: typing.Optional[bilibili.app.card.v1.common_pb2.Base] = ...,
        cover_badge: typing.Text = ...,
        desc: typing.Text = ...,
        title_right_text: typing.Text = ...,
        title_right_pic: builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["base",b"base"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["base",b"base","cover_badge",b"cover_badge","desc",b"desc","title_right_pic",b"title_right_pic","title_right_text",b"title_right_text"]) -> None: ...
global___SmallCoverV4 = SmallCoverV4

class TwoItemV2(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BASE_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    @property
    def base(self) -> bilibili.app.card.v1.common_pb2.Base:
        """"""
        pass
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TwoItemV2Item]:
        """"""
        pass
    def __init__(self,
        *,
        base: typing.Optional[bilibili.app.card.v1.common_pb2.Base] = ...,
        items: typing.Optional[typing.Iterable[global___TwoItemV2Item]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["base",b"base"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["base",b"base","items",b"items"]) -> None: ...
global___TwoItemV2 = TwoItemV2

class TwoItemV2Item(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BASE_FIELD_NUMBER: builtins.int
    BADGE_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_1_FIELD_NUMBER: builtins.int
    COVER_LEFT_ICON_1_FIELD_NUMBER: builtins.int
    @property
    def base(self) -> bilibili.app.card.v1.common_pb2.Base:
        """"""
        pass
    badge: typing.Text
    """"""

    cover_left_text_1: typing.Text
    """"""

    cover_left_icon_1: builtins.int
    """"""

    def __init__(self,
        *,
        base: typing.Optional[bilibili.app.card.v1.common_pb2.Base] = ...,
        badge: typing.Text = ...,
        cover_left_text_1: typing.Text = ...,
        cover_left_icon_1: builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["base",b"base"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["badge",b"badge","base",b"base","cover_left_icon_1",b"cover_left_icon_1","cover_left_text_1",b"cover_left_text_1"]) -> None: ...
global___TwoItemV2Item = TwoItemV2Item

class MultiItem(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BASE_FIELD_NUMBER: builtins.int
    MORE_URI_FIELD_NUMBER: builtins.int
    MORE_TEXT_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    @property
    def base(self) -> bilibili.app.card.v1.common_pb2.Base:
        """"""
        pass
    more_uri: typing.Text
    """"""

    more_text: typing.Text
    """"""

    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DoubleCards]:
        """"""
        pass
    def __init__(self,
        *,
        base: typing.Optional[bilibili.app.card.v1.common_pb2.Base] = ...,
        more_uri: typing.Text = ...,
        more_text: typing.Text = ...,
        items: typing.Optional[typing.Iterable[global___DoubleCards]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["base",b"base"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["base",b"base","items",b"items","more_text",b"more_text","more_uri",b"more_uri"]) -> None: ...
global___MultiItem = MultiItem

class ThreePicV2(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BASE_FIELD_NUMBER: builtins.int
    LEFT_COVER_FIELD_NUMBER: builtins.int
    RIGHT_COVER_1_FIELD_NUMBER: builtins.int
    RIGHT_COVER_2_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_1_FIELD_NUMBER: builtins.int
    COVER_LEFT_ICON_1_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_2_FIELD_NUMBER: builtins.int
    COVER_LEFT_ICON_2_FIELD_NUMBER: builtins.int
    COVER_RIGHT_TEXT_FIELD_NUMBER: builtins.int
    COVER_RIGHT_ICON_FIELD_NUMBER: builtins.int
    COVER_RIGHT_BACKGROUND_COLOR_FIELD_NUMBER: builtins.int
    BADGE_FIELD_NUMBER: builtins.int
    RCMD_REASON_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    AVATAR_FIELD_NUMBER: builtins.int
    RCMD_REASON_STYLE_FIELD_NUMBER: builtins.int
    @property
    def base(self) -> bilibili.app.card.v1.common_pb2.Base:
        """"""
        pass
    left_cover: typing.Text
    """"""

    right_cover_1: typing.Text
    """"""

    right_cover_2: typing.Text
    """"""

    cover_left_text_1: typing.Text
    """"""

    cover_left_icon_1: builtins.int
    """"""

    cover_left_text_2: typing.Text
    """"""

    cover_left_icon_2: builtins.int
    """"""

    cover_right_text: typing.Text
    """"""

    cover_right_icon: builtins.int
    """"""

    cover_right_background_color: typing.Text
    """"""

    badge: typing.Text
    """"""

    rcmd_reason: typing.Text
    """"""

    desc: typing.Text
    """"""

    @property
    def avatar(self) -> bilibili.app.card.v1.common_pb2.Avatar:
        """"""
        pass
    @property
    def rcmd_reason_style(self) -> bilibili.app.card.v1.common_pb2.ReasonStyle:
        """"""
        pass
    def __init__(self,
        *,
        base: typing.Optional[bilibili.app.card.v1.common_pb2.Base] = ...,
        left_cover: typing.Text = ...,
        right_cover_1: typing.Text = ...,
        right_cover_2: typing.Text = ...,
        cover_left_text_1: typing.Text = ...,
        cover_left_icon_1: builtins.int = ...,
        cover_left_text_2: typing.Text = ...,
        cover_left_icon_2: builtins.int = ...,
        cover_right_text: typing.Text = ...,
        cover_right_icon: builtins.int = ...,
        cover_right_background_color: typing.Text = ...,
        badge: typing.Text = ...,
        rcmd_reason: typing.Text = ...,
        desc: typing.Text = ...,
        avatar: typing.Optional[bilibili.app.card.v1.common_pb2.Avatar] = ...,
        rcmd_reason_style: typing.Optional[bilibili.app.card.v1.common_pb2.ReasonStyle] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["avatar",b"avatar","base",b"base","rcmd_reason_style",b"rcmd_reason_style"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["avatar",b"avatar","badge",b"badge","base",b"base","cover_left_icon_1",b"cover_left_icon_1","cover_left_icon_2",b"cover_left_icon_2","cover_left_text_1",b"cover_left_text_1","cover_left_text_2",b"cover_left_text_2","cover_right_background_color",b"cover_right_background_color","cover_right_icon",b"cover_right_icon","cover_right_text",b"cover_right_text","desc",b"desc","left_cover",b"left_cover","rcmd_reason",b"rcmd_reason","rcmd_reason_style",b"rcmd_reason_style","right_cover_1",b"right_cover_1","right_cover_2",b"right_cover_2"]) -> None: ...
global___ThreePicV2 = ThreePicV2

class OnePicV2(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BASE_FIELD_NUMBER: builtins.int
    COVER_LEFT_ICON_1_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_2_FIELD_NUMBER: builtins.int
    COVER_RIGHT_TEXT_FIELD_NUMBER: builtins.int
    COVER_RIGHT_ICON_FIELD_NUMBER: builtins.int
    COVER_RIGHT_BACKGROUND_COLOR_FIELD_NUMBER: builtins.int
    BADGE_FIELD_NUMBER: builtins.int
    RCMD_REASON_FIELD_NUMBER: builtins.int
    AVATAR_FIELD_NUMBER: builtins.int
    RCMD_REASON_STYLE_FIELD_NUMBER: builtins.int
    @property
    def base(self) -> bilibili.app.card.v1.common_pb2.Base:
        """"""
        pass
    cover_left_icon_1: builtins.int
    """"""

    cover_left_text_2: typing.Text
    """"""

    cover_right_text: typing.Text
    """"""

    cover_right_icon: builtins.int
    """"""

    cover_right_background_color: typing.Text
    """"""

    badge: typing.Text
    """"""

    rcmd_reason: typing.Text
    """"""

    @property
    def avatar(self) -> bilibili.app.card.v1.common_pb2.Avatar:
        """"""
        pass
    @property
    def rcmd_reason_style(self) -> bilibili.app.card.v1.common_pb2.ReasonStyle:
        """"""
        pass
    def __init__(self,
        *,
        base: typing.Optional[bilibili.app.card.v1.common_pb2.Base] = ...,
        cover_left_icon_1: builtins.int = ...,
        cover_left_text_2: typing.Text = ...,
        cover_right_text: typing.Text = ...,
        cover_right_icon: builtins.int = ...,
        cover_right_background_color: typing.Text = ...,
        badge: typing.Text = ...,
        rcmd_reason: typing.Text = ...,
        avatar: typing.Optional[bilibili.app.card.v1.common_pb2.Avatar] = ...,
        rcmd_reason_style: typing.Optional[bilibili.app.card.v1.common_pb2.ReasonStyle] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["avatar",b"avatar","base",b"base","rcmd_reason_style",b"rcmd_reason_style"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["avatar",b"avatar","badge",b"badge","base",b"base","cover_left_icon_1",b"cover_left_icon_1","cover_left_text_2",b"cover_left_text_2","cover_right_background_color",b"cover_right_background_color","cover_right_icon",b"cover_right_icon","cover_right_text",b"cover_right_text","rcmd_reason",b"rcmd_reason","rcmd_reason_style",b"rcmd_reason_style"]) -> None: ...
global___OnePicV2 = OnePicV2

class LargeCoverV3(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BASE_FIELD_NUMBER: builtins.int
    COVER_GIF_FIELD_NUMBER: builtins.int
    AVATAR_FIELD_NUMBER: builtins.int
    TOP_RCMD_REASON_STYLE_FIELD_NUMBER: builtins.int
    BOTTOM_RCMD_REASON_STYLE_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_1_FIELD_NUMBER: builtins.int
    COVER_LEFT_ICON_1_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_2_FIELD_NUMBER: builtins.int
    COVER_LEFT_ICON_2_FIELD_NUMBER: builtins.int
    COVER_RIGHT_TEXT_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    OFFICIAL_ICON_FIELD_NUMBER: builtins.int
    @property
    def base(self) -> bilibili.app.card.v1.common_pb2.Base:
        """"""
        pass
    cover_gif: typing.Text
    """"""

    @property
    def avatar(self) -> bilibili.app.card.v1.common_pb2.Avatar:
        """"""
        pass
    @property
    def top_rcmd_reason_style(self) -> bilibili.app.card.v1.common_pb2.ReasonStyle:
        """"""
        pass
    @property
    def bottom_rcmd_reason_style(self) -> bilibili.app.card.v1.common_pb2.ReasonStyle:
        """"""
        pass
    cover_left_text_1: typing.Text
    """"""

    cover_left_icon_1: builtins.int
    """"""

    cover_left_text_2: typing.Text
    """"""

    cover_left_icon_2: builtins.int
    """"""

    cover_right_text: typing.Text
    """"""

    desc: typing.Text
    """"""

    official_icon: builtins.int
    """"""

    def __init__(self,
        *,
        base: typing.Optional[bilibili.app.card.v1.common_pb2.Base] = ...,
        cover_gif: typing.Text = ...,
        avatar: typing.Optional[bilibili.app.card.v1.common_pb2.Avatar] = ...,
        top_rcmd_reason_style: typing.Optional[bilibili.app.card.v1.common_pb2.ReasonStyle] = ...,
        bottom_rcmd_reason_style: typing.Optional[bilibili.app.card.v1.common_pb2.ReasonStyle] = ...,
        cover_left_text_1: typing.Text = ...,
        cover_left_icon_1: builtins.int = ...,
        cover_left_text_2: typing.Text = ...,
        cover_left_icon_2: builtins.int = ...,
        cover_right_text: typing.Text = ...,
        desc: typing.Text = ...,
        official_icon: builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["avatar",b"avatar","base",b"base","bottom_rcmd_reason_style",b"bottom_rcmd_reason_style","top_rcmd_reason_style",b"top_rcmd_reason_style"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["avatar",b"avatar","base",b"base","bottom_rcmd_reason_style",b"bottom_rcmd_reason_style","cover_gif",b"cover_gif","cover_left_icon_1",b"cover_left_icon_1","cover_left_icon_2",b"cover_left_icon_2","cover_left_text_1",b"cover_left_text_1","cover_left_text_2",b"cover_left_text_2","cover_right_text",b"cover_right_text","desc",b"desc","official_icon",b"official_icon","top_rcmd_reason_style",b"top_rcmd_reason_style"]) -> None: ...
global___LargeCoverV3 = LargeCoverV3

class ThreePicV3(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BASE_FIELD_NUMBER: builtins.int
    LEFT_COVER_FIELD_NUMBER: builtins.int
    RIGHT_COVER_1_FIELD_NUMBER: builtins.int
    RIGHT_COVER_2_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_1_FIELD_NUMBER: builtins.int
    COVER_LEFT_ICON_1_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_2_FIELD_NUMBER: builtins.int
    COVER_LEFT_ICON_2_FIELD_NUMBER: builtins.int
    COVER_RIGHT_TEXT_FIELD_NUMBER: builtins.int
    COVER_RIGHT_ICON_FIELD_NUMBER: builtins.int
    COVER_RIGHT_BACKGROUND_COLOR_FIELD_NUMBER: builtins.int
    BADGE_FIELD_NUMBER: builtins.int
    RCMD_REASON_STYLE_FIELD_NUMBER: builtins.int
    @property
    def base(self) -> bilibili.app.card.v1.common_pb2.Base:
        """"""
        pass
    left_cover: typing.Text
    """"""

    right_cover_1: typing.Text
    """"""

    right_cover_2: typing.Text
    """"""

    cover_left_text_1: typing.Text
    """"""

    cover_left_icon_1: builtins.int
    """"""

    cover_left_text_2: typing.Text
    """"""

    cover_left_icon_2: builtins.int
    """"""

    cover_right_text: typing.Text
    """"""

    cover_right_icon: builtins.int
    """"""

    cover_right_background_color: typing.Text
    """"""

    badge: typing.Text
    """"""

    @property
    def rcmd_reason_style(self) -> bilibili.app.card.v1.common_pb2.ReasonStyle:
        """"""
        pass
    def __init__(self,
        *,
        base: typing.Optional[bilibili.app.card.v1.common_pb2.Base] = ...,
        left_cover: typing.Text = ...,
        right_cover_1: typing.Text = ...,
        right_cover_2: typing.Text = ...,
        cover_left_text_1: typing.Text = ...,
        cover_left_icon_1: builtins.int = ...,
        cover_left_text_2: typing.Text = ...,
        cover_left_icon_2: builtins.int = ...,
        cover_right_text: typing.Text = ...,
        cover_right_icon: builtins.int = ...,
        cover_right_background_color: typing.Text = ...,
        badge: typing.Text = ...,
        rcmd_reason_style: typing.Optional[bilibili.app.card.v1.common_pb2.ReasonStyle] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["base",b"base","rcmd_reason_style",b"rcmd_reason_style"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["badge",b"badge","base",b"base","cover_left_icon_1",b"cover_left_icon_1","cover_left_icon_2",b"cover_left_icon_2","cover_left_text_1",b"cover_left_text_1","cover_left_text_2",b"cover_left_text_2","cover_right_background_color",b"cover_right_background_color","cover_right_icon",b"cover_right_icon","cover_right_text",b"cover_right_text","left_cover",b"left_cover","rcmd_reason_style",b"rcmd_reason_style","right_cover_1",b"right_cover_1","right_cover_2",b"right_cover_2"]) -> None: ...
global___ThreePicV3 = ThreePicV3

class OnePicV3(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BASE_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_1_FIELD_NUMBER: builtins.int
    COVER_LEFT_ICON_1_FIELD_NUMBER: builtins.int
    COVER_RIGHT_TEXT_FIELD_NUMBER: builtins.int
    COVER_RIGHT_ICON_FIELD_NUMBER: builtins.int
    COVER_RIGHT_BACKGROUND_COLOR_FIELD_NUMBER: builtins.int
    BADGE_FIELD_NUMBER: builtins.int
    RCMD_REASON_STYLE_FIELD_NUMBER: builtins.int
    @property
    def base(self) -> bilibili.app.card.v1.common_pb2.Base:
        """"""
        pass
    cover_left_text_1: typing.Text
    """"""

    cover_left_icon_1: builtins.int
    """"""

    cover_right_text: typing.Text
    """"""

    cover_right_icon: builtins.int
    """"""

    cover_right_background_color: typing.Text
    """"""

    badge: typing.Text
    """"""

    @property
    def rcmd_reason_style(self) -> bilibili.app.card.v1.common_pb2.ReasonStyle:
        """"""
        pass
    def __init__(self,
        *,
        base: typing.Optional[bilibili.app.card.v1.common_pb2.Base] = ...,
        cover_left_text_1: typing.Text = ...,
        cover_left_icon_1: builtins.int = ...,
        cover_right_text: typing.Text = ...,
        cover_right_icon: builtins.int = ...,
        cover_right_background_color: typing.Text = ...,
        badge: typing.Text = ...,
        rcmd_reason_style: typing.Optional[bilibili.app.card.v1.common_pb2.ReasonStyle] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["base",b"base","rcmd_reason_style",b"rcmd_reason_style"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["badge",b"badge","base",b"base","cover_left_icon_1",b"cover_left_icon_1","cover_left_text_1",b"cover_left_text_1","cover_right_background_color",b"cover_right_background_color","cover_right_icon",b"cover_right_icon","cover_right_text",b"cover_right_text","rcmd_reason_style",b"rcmd_reason_style"]) -> None: ...
global___OnePicV3 = OnePicV3

class SmallCoverV7(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BASE_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    @property
    def base(self) -> bilibili.app.card.v1.common_pb2.Base:
        """"""
        pass
    desc: typing.Text
    """"""

    def __init__(self,
        *,
        base: typing.Optional[bilibili.app.card.v1.common_pb2.Base] = ...,
        desc: typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["base",b"base"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["base",b"base","desc",b"desc"]) -> None: ...
global___SmallCoverV7 = SmallCoverV7

class SmallCoverV9(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BASE_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_1_FIELD_NUMBER: builtins.int
    COVER_LEFT_ICON_1_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_2_FIELD_NUMBER: builtins.int
    COVER_LEFT_ICON_2_FIELD_NUMBER: builtins.int
    COVER_RIGHT_TEXT_FIELD_NUMBER: builtins.int
    COVER_RIGHT_ICON_FIELD_NUMBER: builtins.int
    CAN_PLAY_FIELD_NUMBER: builtins.int
    RCMD_REASON_STYLE_FIELD_NUMBER: builtins.int
    UP_FIELD_NUMBER: builtins.int
    LEFT_COVER_BADGE_STYLE_FIELD_NUMBER: builtins.int
    LEFT_BOTTOM_RCMD_REASON_STYLE_FIELD_NUMBER: builtins.int
    @property
    def base(self) -> bilibili.app.card.v1.common_pb2.Base:
        """"""
        pass
    cover_left_text_1: typing.Text
    """"""

    cover_left_icon_1: builtins.int
    """"""

    cover_left_text_2: typing.Text
    """"""

    cover_left_icon_2: builtins.int
    """"""

    cover_right_text: typing.Text
    """"""

    cover_right_icon: builtins.int
    """"""

    can_play: builtins.int
    """"""

    @property
    def rcmd_reason_style(self) -> bilibili.app.card.v1.common_pb2.ReasonStyle:
        """"""
        pass
    @property
    def up(self) -> bilibili.app.card.v1.common_pb2.Up:
        """"""
        pass
    @property
    def left_cover_badge_style(self) -> bilibili.app.card.v1.common_pb2.ReasonStyle:
        """"""
        pass
    @property
    def left_bottom_rcmd_reason_style(self) -> bilibili.app.card.v1.common_pb2.ReasonStyle:
        """"""
        pass
    def __init__(self,
        *,
        base: typing.Optional[bilibili.app.card.v1.common_pb2.Base] = ...,
        cover_left_text_1: typing.Text = ...,
        cover_left_icon_1: builtins.int = ...,
        cover_left_text_2: typing.Text = ...,
        cover_left_icon_2: builtins.int = ...,
        cover_right_text: typing.Text = ...,
        cover_right_icon: builtins.int = ...,
        can_play: builtins.int = ...,
        rcmd_reason_style: typing.Optional[bilibili.app.card.v1.common_pb2.ReasonStyle] = ...,
        up: typing.Optional[bilibili.app.card.v1.common_pb2.Up] = ...,
        left_cover_badge_style: typing.Optional[bilibili.app.card.v1.common_pb2.ReasonStyle] = ...,
        left_bottom_rcmd_reason_style: typing.Optional[bilibili.app.card.v1.common_pb2.ReasonStyle] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["base",b"base","left_bottom_rcmd_reason_style",b"left_bottom_rcmd_reason_style","left_cover_badge_style",b"left_cover_badge_style","rcmd_reason_style",b"rcmd_reason_style","up",b"up"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["base",b"base","can_play",b"can_play","cover_left_icon_1",b"cover_left_icon_1","cover_left_icon_2",b"cover_left_icon_2","cover_left_text_1",b"cover_left_text_1","cover_left_text_2",b"cover_left_text_2","cover_right_icon",b"cover_right_icon","cover_right_text",b"cover_right_text","left_bottom_rcmd_reason_style",b"left_bottom_rcmd_reason_style","left_cover_badge_style",b"left_cover_badge_style","rcmd_reason_style",b"rcmd_reason_style","up",b"up"]) -> None: ...
global___SmallCoverV9 = SmallCoverV9

class SmallCoverConvergeV2(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BASE_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_1_FIELD_NUMBER: builtins.int
    COVER_LEFT_ICON_1_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_2_FIELD_NUMBER: builtins.int
    COVER_LEFT_ICON_2_FIELD_NUMBER: builtins.int
    COVER_RIGHT_TEXT_FIELD_NUMBER: builtins.int
    COVER_RIGHT_TOP_TEXT_FIELD_NUMBER: builtins.int
    RCMD_REASON_STYLE_FIELD_NUMBER: builtins.int
    RCMD_REASON_STYLE_V2_FIELD_NUMBER: builtins.int
    @property
    def base(self) -> bilibili.app.card.v1.common_pb2.Base:
        """"""
        pass
    cover_left_text_1: typing.Text
    """"""

    cover_left_icon_1: builtins.int
    """"""

    cover_left_text_2: typing.Text
    """"""

    cover_left_icon_2: builtins.int
    """"""

    cover_right_text: typing.Text
    """"""

    cover_right_top_text: typing.Text
    """"""

    @property
    def rcmd_reason_style(self) -> bilibili.app.card.v1.common_pb2.ReasonStyle:
        """"""
        pass
    @property
    def rcmd_reason_style_v2(self) -> bilibili.app.card.v1.common_pb2.ReasonStyle:
        """"""
        pass
    def __init__(self,
        *,
        base: typing.Optional[bilibili.app.card.v1.common_pb2.Base] = ...,
        cover_left_text_1: typing.Text = ...,
        cover_left_icon_1: builtins.int = ...,
        cover_left_text_2: typing.Text = ...,
        cover_left_icon_2: builtins.int = ...,
        cover_right_text: typing.Text = ...,
        cover_right_top_text: typing.Text = ...,
        rcmd_reason_style: typing.Optional[bilibili.app.card.v1.common_pb2.ReasonStyle] = ...,
        rcmd_reason_style_v2: typing.Optional[bilibili.app.card.v1.common_pb2.ReasonStyle] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["base",b"base","rcmd_reason_style",b"rcmd_reason_style","rcmd_reason_style_v2",b"rcmd_reason_style_v2"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["base",b"base","cover_left_icon_1",b"cover_left_icon_1","cover_left_icon_2",b"cover_left_icon_2","cover_left_text_1",b"cover_left_text_1","cover_left_text_2",b"cover_left_text_2","cover_right_text",b"cover_right_text","cover_right_top_text",b"cover_right_top_text","rcmd_reason_style",b"rcmd_reason_style","rcmd_reason_style_v2",b"rcmd_reason_style_v2"]) -> None: ...
global___SmallCoverConvergeV2 = SmallCoverConvergeV2

class SmallChannelSpecial(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BASE_FIELD_NUMBER: builtins.int
    BG_COVER_FIELD_NUMBER: builtins.int
    DESC_1_FIELD_NUMBER: builtins.int
    DESC_2_FIELD_NUMBER: builtins.int
    BADGE_FIELD_NUMBER: builtins.int
    RCMD_REASON_STYLE_2_FIELD_NUMBER: builtins.int
    @property
    def base(self) -> bilibili.app.card.v1.common_pb2.Base:
        """"""
        pass
    bg_cover: typing.Text
    """"""

    desc_1: typing.Text
    """"""

    desc_2: typing.Text
    """"""

    badge: typing.Text
    """"""

    @property
    def rcmd_reason_style_2(self) -> bilibili.app.card.v1.common_pb2.ReasonStyle:
        """"""
        pass
    def __init__(self,
        *,
        base: typing.Optional[bilibili.app.card.v1.common_pb2.Base] = ...,
        bg_cover: typing.Text = ...,
        desc_1: typing.Text = ...,
        desc_2: typing.Text = ...,
        badge: typing.Text = ...,
        rcmd_reason_style_2: typing.Optional[bilibili.app.card.v1.common_pb2.ReasonStyle] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["base",b"base","rcmd_reason_style_2",b"rcmd_reason_style_2"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["badge",b"badge","base",b"base","bg_cover",b"bg_cover","desc_1",b"desc_1","desc_2",b"desc_2","rcmd_reason_style_2",b"rcmd_reason_style_2"]) -> None: ...
global___SmallChannelSpecial = SmallChannelSpecial



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/community/service/govern/v1/govern.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1bilibili/community/service/govern/v1/govern.proto\x12$bilibili.community.service.govern.v1\x1a\x1bgoogle/protobuf/empty.proto\"\xc1\x01\n\x0cQoeReportReq\x12\n\n\x02id\x18\x01 \x01(\x03\x12\r\n\x05scene\x18\x02 \x01(\x03\x12\x0c\n\x04type\x18\x03 \x01(\x05\x12\x0e\n\x06\x63\x61ncel\x18\x04 \x01(\x08\x12\x15\n\rbusiness_type\x18\x05 \x01(\t\x12J\n\x0cscore_result\x18\x06 \x01(\x0b\x32\x34.bilibili.community.service.govern.v1.QoeScoreResult\x12\x15\n\rbusiness_data\x18\x07 \x01(\t\"\x1f\n\x0eQoeScoreResult\x12\r\n\x05score\x18\x01 \x01(\x02\x32^\n\x03Qoe\x12W\n\tQoeReport\x12\x32.bilibili.community.service.govern.v1.QoeReportReq\x1a\x16.google.protobuf.Emptyb\x06proto3')



_QOEREPORTREQ = DESCRIPTOR.message_types_by_name['QoeReportReq']
_QOESCORERESULT = DESCRIPTOR.message_types_by_name['QoeScoreResult']
QoeReportReq = _reflection.GeneratedProtocolMessageType('QoeReportReq', (_message.Message,), {
  'DESCRIPTOR' : _QOEREPORTREQ,
  '__module__' : 'bilibili.community.service.govern.v1.govern_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.community.service.govern.v1.QoeReportReq)
  })
_sym_db.RegisterMessage(QoeReportReq)

QoeScoreResult = _reflection.GeneratedProtocolMessageType('QoeScoreResult', (_message.Message,), {
  'DESCRIPTOR' : _QOESCORERESULT,
  '__module__' : 'bilibili.community.service.govern.v1.govern_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.community.service.govern.v1.QoeScoreResult)
  })
_sym_db.RegisterMessage(QoeScoreResult)

_QOE = DESCRIPTOR.services_by_name['Qoe']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _QOEREPORTREQ._serialized_start=121
  _QOEREPORTREQ._serialized_end=314
  _QOESCORERESULT._serialized_start=316
  _QOESCORERESULT._serialized_end=347
  _QOE._serialized_start=349
  _QOE._serialized_end=443
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/app/wall/v1/wall.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x62ilibili/app/wall/v1/wall.proto\x12\x14\x62ilibili.app.wall.v1\"\r\n\x0bRuleRequest\"\xa3\x01\n\nRulesReply\x12\x42\n\trulesInfo\x18\x01 \x03(\x0b\x32/.bilibili.app.wall.v1.RulesReply.RulesInfoEntry\x1aQ\n\x0eRulesInfoEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12.\n\x05value\x18\x02 \x01(\x0b\x32\x1f.bilibili.app.wall.v1.RulesInfo:\x02\x38\x01\"7\n\x08RuleInfo\x12\n\n\x02tf\x18\x01 \x01(\x08\x12\t\n\x01m\x18\x02 \x01(\t\x12\t\n\x01\x61\x18\x03 \x01(\t\x12\t\n\x01p\x18\x04 \x01(\t\">\n\tRulesInfo\x12\x31\n\trulesInfo\x18\x01 \x03(\x0b\x32\x1e.bilibili.app.wall.v1.RuleInfo2W\n\x04Wall\x12O\n\x08RuleInfo\x12!.bilibili.app.wall.v1.RuleRequest\x1a .bilibili.app.wall.v1.RulesReplyb\x06proto3')



_RULEREQUEST = DESCRIPTOR.message_types_by_name['RuleRequest']
_RULESREPLY = DESCRIPTOR.message_types_by_name['RulesReply']
_RULESREPLY_RULESINFOENTRY = _RULESREPLY.nested_types_by_name['RulesInfoEntry']
_RULEINFO = DESCRIPTOR.message_types_by_name['RuleInfo']
_RULESINFO = DESCRIPTOR.message_types_by_name['RulesInfo']
RuleRequest = _reflection.GeneratedProtocolMessageType('RuleRequest', (_message.Message,), {
  'DESCRIPTOR' : _RULEREQUEST,
  '__module__' : 'bilibili.app.wall.v1.wall_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.wall.v1.RuleRequest)
  })
_sym_db.RegisterMessage(RuleRequest)

RulesReply = _reflection.GeneratedProtocolMessageType('RulesReply', (_message.Message,), {

  'RulesInfoEntry' : _reflection.GeneratedProtocolMessageType('RulesInfoEntry', (_message.Message,), {
    'DESCRIPTOR' : _RULESREPLY_RULESINFOENTRY,
    '__module__' : 'bilibili.app.wall.v1.wall_pb2'
    # @@protoc_insertion_point(class_scope:bilibili.app.wall.v1.RulesReply.RulesInfoEntry)
    })
  ,
  'DESCRIPTOR' : _RULESREPLY,
  '__module__' : 'bilibili.app.wall.v1.wall_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.wall.v1.RulesReply)
  })
_sym_db.RegisterMessage(RulesReply)
_sym_db.RegisterMessage(RulesReply.RulesInfoEntry)

RuleInfo = _reflection.GeneratedProtocolMessageType('RuleInfo', (_message.Message,), {
  'DESCRIPTOR' : _RULEINFO,
  '__module__' : 'bilibili.app.wall.v1.wall_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.wall.v1.RuleInfo)
  })
_sym_db.RegisterMessage(RuleInfo)

RulesInfo = _reflection.GeneratedProtocolMessageType('RulesInfo', (_message.Message,), {
  'DESCRIPTOR' : _RULESINFO,
  '__module__' : 'bilibili.app.wall.v1.wall_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.wall.v1.RulesInfo)
  })
_sym_db.RegisterMessage(RulesInfo)

_WALL = DESCRIPTOR.services_by_name['Wall']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _RULESREPLY_RULESINFOENTRY._options = None
  _RULESREPLY_RULESINFOENTRY._serialized_options = b'8\001'
  _RULEREQUEST._serialized_start=57
  _RULEREQUEST._serialized_end=70
  _RULESREPLY._serialized_start=73
  _RULESREPLY._serialized_end=236
  _RULESREPLY_RULESINFOENTRY._serialized_start=155
  _RULESREPLY_RULESINFOENTRY._serialized_end=236
  _RULEINFO._serialized_start=238
  _RULEINFO._serialized_end=293
  _RULESINFO._serialized_start=295
  _RULESINFO._serialized_end=357
  _WALL._serialized_start=359
  _WALL._serialized_end=446
# @@protoc_insertion_point(module_scope)
